@@ -10,7 +10,8 @@ from matplotlib.axes import Axes
 from spiceypy.utils.exceptions import NotFoundError
 
 from . import data_loader, utils
-from .base import SpiceBase
+from .base import SpiceBase, Numeric
+
 
 class Body(SpiceBase):
     """
@@ -22,19 +23,24 @@ class Body(SpiceBase):
     that are passed to SPICE functions which can almost always be left as their default
     values.
 
+    The `target` and `observer` names are passed to 
+    :func:`SpiceBase.standardise_body_name`, so a variety of formats are acceptable. For
+    example `'jupiter'`, `'JUPITER'`, `' Jupiter '`, `'599'` and `599` will
+    all resolve to `'JUPITER'`.
+
     This class inherits from :class:`SpiceBase` so the methods described above are also
     available.
 
     Args:
         target: Name of target body.
         utc: Time of observation. This can be provided in a variety of formats and is
-            assumed to be UTC unless otherwised specified. The accepted formats are: any
+            assumed to be UTC unless otherwise specified. The accepted formats are: any
             `string` datetime representation compatible with SPICE (e.g.
             `'2000-12-31T23:59:59'` - see
             https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/utc2et_c.html
             for the acceptable string formats), a Python `datetime` object, or a `float`
             representing the Modified Julian Date (MJD) of the observation.
-        observer: Name of observing body. Defaults to 'EARTH'.
+        observer: Name of observing body. Defaults to `'EARTH'`.
         observer_frame: Observer reference frame.
         illumination_source: Illumination source (e.g. the sun).
         aberration_correction: Aberration correction used to correct light travel time
@@ -46,9 +52,9 @@ class Body(SpiceBase):
 
     def __init__(
         self,
-        target: str,
+        target: str|int,
         utc: str | datetime.datetime | float,
-        observer: str = 'EARTH',
+        observer: str|int = 'EARTH',
         *,
         observer_frame: str = 'J2000',
         illumination_source: str = 'SUN',
@@ -753,7 +759,30 @@ class Body(SpiceBase):
         phase, incdnc, emissn = self._illumination_angles_from_targvec_radians(
             self.lonlat2targvec(lon, lat)
         )
-        return np.deg2rad(phase), np.deg2rad(incdnc), np.deg2rad(emissn)
+        return np.rad2deg(phase), np.rad2deg(incdnc), np.rad2deg(emissn)
+
+    def _azimuth_angle_from_gie_radians(self, phase_radians: Numeric,incidence_radians:Numeric, emission_radians:Numeric) -> Numeric:
+        # Based on Henrik's code at:
+        # https://github.com/JWSTGiantPlanets/NIRSPEC-Toolkit/blob/5e2e2cc/JWSTSolarSystemPointing.py#L204-L209
+        a = np.cos(phase_radians) - np.cos(emission_radians) * np.cos(incidence_radians)
+        b = np.sqrt(1.0 - np.cos(emission_radians) ** 2) * np.sqrt(1.0 - np.cos(incidence_radians) ** 2)
+        azimuth_radians = np.pi - np.arccos(a / b)
+        return azimuth_radians
+
+    def azimuth_angle_from_lonlat(self, lon: float, lat: float) -> float:
+        """
+        Calculate the azimuth angle of a longitude/latitude coordinate on the target 
+        body.
+
+        Args:
+            lon: Longitude of point on target body.
+            lat: Latitude of point on target body.
+
+        Returns:
+            Azimuth angle in degrees.
+        """
+        azimuth_radians = self._azimuth_angle_from_gie_radians(*self._illumination_angles_from_targvec_radians(self.lonlat2targvec(lon, lat)))
+        return np.rad2deg(azimuth_radians)
 
     def terminator_radec(
         self,
@@ -863,7 +892,7 @@ class Body(SpiceBase):
         arrays of RA and Dec coordinates. Coordinates which correspond to points which
         are not visible are replaced with NaN.
 
-        See also :func:`visible_latlon_grid_radec`,
+        See also :func:`visible_lonlat_grid_radec`,
 
         Args:
             lons: List of longitudes to plot.
@@ -888,7 +917,7 @@ class Body(SpiceBase):
     ) -> list[tuple[np.ndarray, np.ndarray]]:
         """
         Constant latitude version of :func:`visible_lon_grid_radec`. See also
-        :func:`visible_latlon_grid_radec`.
+        :func:`visible_lonlat_grid_radec`.
 
         Args:
             lats: List of latitudes to plot.
@@ -1015,6 +1044,10 @@ class Body(SpiceBase):
         return ra_arr, dec_arr
 
     # Planetographic <-> planetocentric
+    def _targvec2lonlat_centric(self, targvec: np.ndarray) -> tuple[float, float]:
+        radius, lon_centric, lat_centric = spice.reclat(targvec)
+        return self._radian_pair2degrees(lon_centric, lat_centric)
+
     def graphic2centric_lonlat(self, lon: float, lat: float) -> tuple[float, float]:
         """
         Convert planetographic longitude/latitude to planetocentric.
@@ -1026,21 +1059,20 @@ class Body(SpiceBase):
         Returns:
             `(lon_centric, lat_centric)` tuple of planetocentric coordinates.
         """
-        radius, lon_centric, lat_centric = spice.reclat(self.lonlat2targvec(lon, lat))
-        return self._radian_pair2degrees(lon_centric, lat_centric)
+        return self._targvec2lonlat_centric(self.lonlat2targvec(lon, lat))
 
     def centric2graphic_lonlat(
         self, lon_centric: float, lat_centric: float
     ) -> tuple[float, float]:
         """
-        Convert planetocentric longitude/latitude to planetographicg.
+        Convert planetocentric longitude/latitude to planetographic.
 
         Args:
             lon_centric: Planetocentric longitude.
             lat_centric: Planetographic latitude.
 
         Returns:
-            `(lon, lat)` tuple of plenetographic coordinates.
+            `(lon, lat)` tuple of planetographic coordinates.
         """
         targvec = spice.latsrf(
             self._surface_method_encoded,  # type: ignore
@@ -1053,7 +1085,13 @@ class Body(SpiceBase):
 
     # Other
     def north_pole_angle(self) -> float:
-        # TODO docstring
+        """
+        Calculate the angle of the north pole of the target body relative to the 
+        positive declination direction.
+
+        Returns:
+            Angle of the north pole in degrees.
+        """
         np_ra, np_dec = self.lonlat2radec(0, 90)
         theta = np.arctan2(self.target_ra - np_ra, np_dec - self.target_dec)
         return np.rad2deg(theta)
