@@ -11,6 +11,7 @@ from typing import (
     Protocol,
     TypeVar,
 )
+import warnings
 
 import matplotlib.patches
 import matplotlib.pyplot as plt
@@ -132,7 +133,7 @@ class BodyXY(Body):
     `r0` and the `rotation` of the disc. These disc parameters can be adjusted using
     methods such as :func:`set_x0` and retrieved using methods such as :func:`get_x0`.
     It is important to note that conversions involving `xy` image pixel coordinates
-    (e.g. backplane image generatiton) will produce different results before and after
+    (e.g. backplane image generation) will produce different results before and after
     these disc parameter values are adjusted.
 
     For larger images, the generation of backplane images can be computationally
@@ -168,7 +169,7 @@ class BodyXY(Body):
     The size of the image can be specified by using the `nx` and `ny` parameters to
     specify the number of pixels in the x and y dimensions of the image respectively.
     If `nx` and `ny` are equal (i.e. the image is square), then the parameter `sz` can
-    be used instead to set both `nx` and `ny`, where `BodyXY(..., sz=50)` is equivilent
+    be used instead to set both `nx` and `ny`, where `BodyXY(..., sz=50)` is equivalent
     to `BodyXY(..., nx=50, ny=50)`.
 
     If `nx` and `ny` are not set, then some functionality (such as generating backplane
@@ -181,7 +182,7 @@ class BodyXY(Body):
         nx: Number of pixels in the x dimension of the image.
         ny: Number of pixels in the y dimension of the image.
         sz: Convenience parameter to set both `nx` and `ny` to the same value.
-            `BodyXY(..., sz=50)` is equivilent to `BodyXY(..., nx=50, ny=50)`. If `sz`
+            `BodyXY(..., sz=50)` is equivalent to `BodyXY(..., nx=50, ny=50)`. If `sz`
             is defined along with `nx` or `ny` then a `ValueError` is raised.
         **kwargs: Additional arguments are passed to :class:`Body`.
     """
@@ -209,8 +210,8 @@ class BodyXY(Body):
         self.backplanes: dict[str, Backplane]
         """
         Dictionary containing registered backplanes which can be used to calculate
-        properties (e.g. longitude/latitutde, illumination angles etc.) for each pixel 
-        in the image.
+        properties (e.g. longitude/latitude, illumination angles etc.) for each pixel in
+        the image.
 
         By default, this dictionary contains a series of 
         :ref:`default backplanes <default backplanes>`. These can be summarised using 
@@ -366,7 +367,7 @@ class BodyXY(Body):
             **kwargs: Additional arguments are passed to :func:`Body.radec2lonlat`.
 
         Returns:
-            `(lon, lat)` tuple containing the longittude and latitude of the point. If
+            `(lon, lat)` tuple containing the longitude and latitude of the point. If
             the provided pixel coordinates are missing the target body, then the `lon`
             and `lat` values will both be NaN (see :func:`Body.radec2lonlat`).
         """
@@ -407,15 +408,15 @@ class BodyXY(Body):
         """
         Convenience function to set multiple disc parameters at once.
 
-        For example, `body.set_disc_params(x0=10, r0=5)` is equivilent to calling
+        For example, `body.set_disc_params(x0=10, r0=5)` is equivalent to calling
         `body.set_x0(10)` and `body.set_r0(5)`. Any unspecified parameters will be left
         unchanged.
 
         Args:
-            x0: If specified, passsed to :func:`set_x0`.
-            y0: If specified, passsed to :func:`set_y0`.
-            r0: If specified, passsed to :func:`set_r0`.
-            rotation: If specified, passsed to :func:`set_rotation`.
+            x0: If specified, passed to :func:`set_x0`.
+            y0: If specified, passed to :func:`set_y0`.
+            r0: If specified, passed to :func:`set_r0`.
+            rotation: If specified, passed to :func:`set_rotation`.
         """
         if x0 is not None:
             self.set_x0(x0)
@@ -437,7 +438,7 @@ class BodyXY(Body):
 
             body.adjust_disc_params(dy=-3.1, drotation=42)
 
-        is equivilent to ::
+        is equivalent to ::
 
             body.set_y0(body.get_y0() - 3.1)
             body.set_rotation(body.get_rotation() + 42)
@@ -471,7 +472,7 @@ class BodyXY(Body):
             x0: New x pixel coordinate of the centre of the target body.
 
         Raises:
-            ValueEror: if `x0` is not finite.
+            ValueError: if `x0` is not finite.
         """
         if not math.isfinite(x0):
             raise ValueError('x0 must be finite')
@@ -491,7 +492,7 @@ class BodyXY(Body):
             y0: New y pixel coordinate of the centre of the target body.
 
         Raises:
-            ValueEror: if `y0` is not finite.
+            ValueError: if `y0` is not finite.
         """
         if not math.isfinite(y0):
             raise ValueError('y0 must be finite')
@@ -540,13 +541,13 @@ class BodyXY(Body):
 
         This rotation defines the angle between the upwards (positive `dec`) direction
         in the RA/Dec sky coordinates and the upwards (positive `y`) direction in the
-        image pixel coordinaates.
+        image pixel coordinates.
 
         Args:
             rotation: New rotation of the target body.
 
         Raises:
-            ValueEror: if `rotation` is not finite.
+            ValueError: if `rotation` is not finite.
         """
         if not math.isfinite(rotation):
             raise ValueError('rotation must be finite')
@@ -573,7 +574,7 @@ class BodyXY(Body):
         Sets the plate scale of the observation by changing `r0`.
 
         Args:
-            km_per_px: Kilometers per pixel plate scale at the target body.
+            km_per_px: Kilometres per pixel plate scale at the target body.
         """
         self.set_r0(self.r_eq / km_per_px)
 
@@ -597,8 +598,8 @@ class BodyXY(Body):
         dimension of the image respectively. Unspecified values will remain unchanged.
 
         Args:
-            nx: If specified, set the numebr of pixels in the x dimension.
-            ny: If specified, set the numebr of pixels in the y dimension.
+            nx: If specified, set the number of pixels in the x dimension.
+            ny: If specified, set the number of pixels in the y dimension.
         """
         if nx is not None:
             self._nx = nx
@@ -712,7 +713,7 @@ class BodyXY(Body):
 
         Args:
             radius: Radius in km of the ring from the centre of the target body.
-            **kwargs: Passedd to :func:`Body.ring_radec`.
+            **kwargs: Passed to :func:`Body.ring_radec`.
 
         Returns:
             `(x, y)` tuple of coordinate arrays.
@@ -902,7 +903,7 @@ class BodyXY(Body):
         Create a standardised version of a backplane name when finding and registering
         backplanes.
 
-        This standardisatiton is used in functions like :func:`get_backplane_img` and
+        This standardisation is used in functions like :func:`get_backplane_img` and
         :func:`plot_backplane` so that, for example `body.plot_backplane('LAT')`,
         `body.plot_backplane('Lat')` and `body.plot_backplane('lat')` all produce the
         same plot.
@@ -933,7 +934,7 @@ class BodyXY(Body):
                 :func:`standardise_backplane_name` before being registered.
             description: Longer description of backplane, including units.
             get_img: Function to generate backplane image.
-            get_map: Function to generate bakplane map.
+            get_map: Function to generate backplane map.
 
         Raises:
             ValueError: if provided backplane name is already registered.
@@ -949,7 +950,7 @@ class BodyXY(Body):
     def backplane_summary_string(self) -> str:
         """
         Returns:
-            String summaring currently registered :attr:`backplanes`.
+            String summarising currently registered :attr:`backplanes`.
         """
         return '\n'.join(
             f'{bp.name}: {bp.description}' for bp in self.backplanes.values()
@@ -965,7 +966,7 @@ class BodyXY(Body):
         """
         Convenience function to retrieve a backplane registered to :attr:`backplanes`.
 
-        This method is equivilent to ::
+        This method is equivalent to ::
 
             body.backplanes[self.standardise_backplane_name(name)]
 
@@ -1002,7 +1003,7 @@ class BodyXY(Body):
         returned image can be safely modified without affecting the cached value (unlike
         the return values from functions such as :func:`get_lon_img`).
 
-        This method is equivilent to ::
+        This method is equivalent to ::
 
             body.get_backplane(name).get_img().copy()
 
@@ -1024,7 +1025,7 @@ class BodyXY(Body):
         safely modified without affecting the cached value (unlike the return values
         from functions such as :func:`get_lon_map`).
 
-        This method is equivilent to ::
+        This method is equivalent to ::
 
             body.get_backplane(name).get_map(degree_interval).copy()
 
@@ -1131,82 +1132,6 @@ class BodyXY(Body):
             plt.show()
         return ax
 
-    def _register_default_backplanes(self) -> None:
-        self.register_backplane(
-            'LON-GRAPHIC',
-            'Planetographic longitude, positive {ew} [deg]'.format(
-                ew=self.positive_longitude_direction
-            ),
-            self.get_lon_img,
-            self.get_lon_map,
-        )
-        self.register_backplane(
-            'LAT-GRAPHIC',
-            'Planetographic latitude [deg]',
-            self.get_lat_img,
-            self.get_lat_map,
-        )
-        self.register_backplane(
-            'RA',
-            'Right ascension [deg]',
-            self.get_ra_img,
-            self.get_ra_map,
-        )
-        self.register_backplane(
-            'DEC',
-            'Declination [deg]',
-            self.get_dec_img,
-            self.get_dec_map,
-        )
-        self.register_backplane(
-            'PIXEL-X',
-            'Observation x pixel coordinate [pixels]',
-            self.get_x_img,
-            self.get_x_map,
-        )
-        self.register_backplane(
-            'PIXEL-Y',
-            'Observation y pixel coordinate [pixels]',
-            self.get_y_img,
-            self.get_y_map,
-        )
-        self.register_backplane(
-            'PHASE',
-            'Phase angle [deg]',
-            self.get_phase_angle_img,
-            self.get_phase_angle_map,
-        )
-        self.register_backplane(
-            'INCIDENCE',
-            'Incidence angle [deg]',
-            self.get_incidence_angle_img,
-            self.get_incidence_angle_map,
-        )
-        self.register_backplane(
-            'EMISSION',
-            'Emission angle [dec]',
-            self.get_emission_angle_img,
-            self.get_emission_angle_map,
-        )
-        self.register_backplane(
-            'DISTANCE',
-            'Distance to observer [km]',
-            self.get_distance_img,
-            self.get_distance_map,
-        )
-        self.register_backplane(
-            'RADIAL-VELOCITY',
-            'Radial velocity away from observer [km/s]',
-            self.get_radial_velocity_img,
-            self.get_radial_velocity_map,
-        )
-        self.register_backplane(
-            'DOPPLER',
-            'Doppler factor, sqrt((1 + v/c)/(1 - v/c)) where v is radial velocity',
-            self.get_doppler_img,
-            self.get_doppler_map,
-        )
-
     # Backplane generatotrs
     def _test_if_img_size_valid(self) -> bool:
         return (self._nx > 0) and (self._ny > 0)
@@ -1344,8 +1269,8 @@ class BodyXY(Body):
         See also :func:`get_backplane_img`.
 
         Returns:
-            Array containing the longitude value of each pixel in the image. Points off
-            the disc have a value of NaN.
+            Array containing the planetographic longitude value of each pixel in the 
+            image. Points off the disc have a value of NaN.
         """
         return self._get_lonlat_img()[:, :, 0]
 
@@ -1357,7 +1282,7 @@ class BodyXY(Body):
             degree_interval: Interval in degrees between points in the returned map.
 
         Returns:
-            Array containing cylindrical map of longitude values.
+            Array containing cylindrical map of planetographic longitude values.
         """
         return self._get_lonlat_map(degree_interval)[:, :, 0]
 
@@ -1366,8 +1291,8 @@ class BodyXY(Body):
         See also :func:`get_backplane_img`.
 
         Returns:
-            Array containing the latiutude value of each pixel in the image. Points off
-            the disc have a value of NaN.
+            Array containing the planetographic latitude value of each pixel in the 
+            image. Points off the disc have a value of NaN.
         """
         return self._get_lonlat_img()[:, :, 1]
 
@@ -1379,10 +1304,73 @@ class BodyXY(Body):
             degree_interval: Interval in degrees between points in the returned map.
 
         Returns:
-            Array containing cylindrical map of latitude values.
+            Array containing cylindrical map of planetographic latitude values.
         """
         return self._get_lonlat_map(degree_interval)[:, :, 1]
 
+    @_cache_clearable_result
+    @progress_decorator
+    def _get_lonlat_centric_img(self) -> np.ndarray:
+        out = self._make_empty_img(2)
+        for y, x, targvec in self._enumerate_targvec_img(progress=True):
+            out[y, x] = self._targvec2lonlat_centric(targvec)
+        return out
+    
+
+    @_cache_stable_result
+    @progress_decorator
+    def _get_lonlat_centric_map(self, degree_interval: float) -> np.ndarray:
+        out = self._make_empty_map(degree_interval, 2)
+        for a, b, targvec in self._enumerate_targvec_map(
+            degree_interval, progress=True
+        ):
+            out[a, b] = self._targvec2lonlat_centric(targvec)
+        return out
+
+    def get_lon_centric_img(self) -> np.ndarray:
+        """
+        See also :func:`get_backplane_img`.
+
+        Returns:
+            Array containing the planetocentric longitude value of each pixel in the
+            image. Points off the disc have a value of NaN.
+        """
+        return self._get_lonlat_centric_img()[:, :, 0]
+
+    def get_lon_centric_map(self, degree_interval: float = 1) -> np.ndarray:
+        """
+        See also :func:`get_backplane_map`.
+
+        Args:
+            degree_interval: Interval in degrees between points in the returned map.
+
+        Returns:
+            Array containing cylindrical map of planetocentric longitude values.
+        """
+        return self._get_lonlat_centric_map(degree_interval)[:, :, 0]
+
+    def get_lat_centric_img(self) -> np.ndarray:
+        """
+        See also :func:`get_backplane_img`.
+
+        Returns:
+            Array containing the planetocentric latitude value of each pixel in the
+            image. Points off the disc have a value of NaN.
+        """
+        return self._get_lonlat_centric_img()[:, :, 1]
+
+    def get_lat_centric_map(self, degree_interval: float = 1) -> np.ndarray:
+        """
+        See also :func:`get_backplane_map`.
+
+        Args:
+            degree_interval: Interval in degrees between points in the returned map.
+
+        Returns:
+            Array containing cylindrical map of planetocentric latitude values.
+        """
+        return self._get_lonlat_centric_map(degree_interval)[:, :, 1]
+
     @_cache_clearable_result
     @progress_decorator
     def _get_radec_img(self) -> np.ndarray:
@@ -1515,7 +1503,6 @@ class BodyXY(Body):
     def _get_illumination_gie_img(self) -> np.ndarray:
         out = self._make_empty_img(3)
         for y, x, targvec in self._enumerate_targvec_img(progress=True):
-            self._update_progress_hook(y / self._ny)
             out[y, x] = self._illumination_angles_from_targvec_radians(targvec)
         return np.rad2deg(out)
 
@@ -1598,6 +1585,47 @@ class BodyXY(Body):
         """
         return self._get_illumf_map(degree_interval)[:, :, 2]
 
+    @_cache_clearable_result
+    def get_azimuth_angle_img(self) -> np.ndarray:
+        """
+        See also :func:`get_backplane_img`.
+
+        Returns:
+            Array containing the azimuth angle value of each pixel in the image. Points
+            off the disc have a value of NaN.
+        """
+        phase_radians = self._get_illumination_gie_img()[:, :, 0]
+        incidence_radians= self._get_illumination_gie_img()[:, :, 1]
+        emission_radians = self._get_illumination_gie_img()[:, :, 2]
+        with warnings.catch_warnings():
+            # TODO should we do this better?
+            warnings.filterwarnings('ignore', 'divide by zero encountered in')
+            warnings.filterwarnings('ignore', 'invalid value encountered in')
+            azimuth_radians = self._azimuth_angle_from_gie_radians(phase_radians, incidence_radians,emission_radians)
+        return np.rad2deg(azimuth_radians)
+    
+    @_cache_stable_result
+    def get_azimuth_angle_map(self, degree_interval: float = 1) -> np.ndarray:
+        """
+        See also :func:`get_backplane_map`.
+
+        Args:
+            degree_interval: Interval in degrees between points in the returned map.
+
+        Returns:
+            Array containing cylindrical map of the azimuth angle value at each point
+            on the target's surface.
+        """
+        phase_radians = self._get_illumf_map(degree_interval)[:, :, 0]
+        incidence_radians= self._get_illumf_map(degree_interval)[:, :, 1]
+        emission_radians = self._get_illumf_map(degree_interval)[:, :, 2]
+        with warnings.catch_warnings():
+            # TODO should we do this better?
+            warnings.filterwarnings('ignore', 'divide by zero encountered in')
+            warnings.filterwarnings('ignore', 'invalid value encountered in')
+            azimuth_radians = self._azimuth_angle_from_gie_radians(phase_radians, incidence_radians,emission_radians)
+        return np.rad2deg(azimuth_radians)
+
     @_cache_clearable_result
     @progress_decorator
     def _get_state_imgs(self) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
@@ -1684,7 +1712,7 @@ class BodyXY(Body):
             degree_interval: Interval in degrees between points in the returned map.
 
         Returns:
-            Array containing cylindrical map of the observer-traget radial velocity in
+            Array containing cylindrical map of the observer-target radial velocity in
             km/s of each point on the target's surface.
         """
         out = self._make_empty_map(degree_interval)
@@ -1724,6 +1752,101 @@ class BodyXY(Body):
         return self.calculate_doppler_factor(
             self.get_radial_velocity_map(degree_interval)
         )
+    
+    # Default backplane registration
+    def _register_default_backplanes(self) -> None:
+        self.register_backplane(
+            'LON-GRAPHIC',
+            'Planetographic longitude, positive {ew} [deg]'.format(
+                ew=self.positive_longitude_direction
+            ),
+            self.get_lon_img,
+            self.get_lon_map,
+        )
+        self.register_backplane(
+            'LAT-GRAPHIC',
+            'Planetographic latitude [deg]',
+            self.get_lat_img,
+            self.get_lat_map,
+        )
+        self.register_backplane(
+            'LON-CENTRIC',
+            'Planetocentric longitude [deg]',
+            self.get_lon_centric_img,
+            self.get_lon_centric_map,
+        )
+        self.register_backplane(
+            'LAT-CENTRIC',
+            'Planetocentric latitude [deg]',
+            self.get_lat_centric_img,
+            self.get_lat_centric_map,
+        )
+        self.register_backplane(
+            'RA',
+            'Right ascension [deg]',
+            self.get_ra_img,
+            self.get_ra_map,
+        )
+        self.register_backplane(
+            'DEC',
+            'Declination [deg]',
+            self.get_dec_img,
+            self.get_dec_map,
+        )
+        self.register_backplane(
+            'PIXEL-X',
+            'Observation x pixel coordinate [pixels]',
+            self.get_x_img,
+            self.get_x_map,
+        )
+        self.register_backplane(
+            'PIXEL-Y',
+            'Observation y pixel coordinate [pixels]',
+            self.get_y_img,
+            self.get_y_map,
+        )
+        self.register_backplane(
+            'PHASE',
+            'Phase angle [deg]',
+            self.get_phase_angle_img,
+            self.get_phase_angle_map,
+        )
+        self.register_backplane(
+            'INCIDENCE',
+            'Incidence angle [deg]',
+            self.get_incidence_angle_img,
+            self.get_incidence_angle_map,
+        )
+        self.register_backplane(
+            'EMISSION',
+            'Emission angle [deg]',
+            self.get_emission_angle_img,
+            self.get_emission_angle_map,
+        )
+        self.register_backplane(
+            'AZIMUTH',
+            'Azimuth angle [deg]',
+            self.get_azimuth_angle_img,
+            self.get_azimuth_angle_map,
+        )
+        self.register_backplane(
+            'DISTANCE',
+            'Distance to observer [km]',
+            self.get_distance_img,
+            self.get_distance_map,
+        )
+        self.register_backplane(
+            'RADIAL-VELOCITY',
+            'Radial velocity away from observer [km/s]',
+            self.get_radial_velocity_img,
+            self.get_radial_velocity_map,
+        )
+        self.register_backplane(
+            'DOPPLER',
+            'Doppler factor, sqrt((1 + v/c)/(1 - v/c)) where v is radial velocity',
+            self.get_doppler_img,
+            self.get_doppler_map,
+        )
 
 
 class BackplaneNotFoundError(Exception):
@@ -1757,8 +1880,6 @@ def _make_backplane_documentation_str() -> str:
     msg.append('')
 
     for bp in body.backplanes.values():
-        # msg.append('`{}`'.format(bp.name))
-        # msg.append('=' * len(msg[-1]))
         msg.append('------------')
         msg.append('')
         msg.append('`{}` {}'.format(bp.name, bp.description))
